/*!
    \file   cstart.cpp
    \brief  mona kernel start at this point

    mona kernel start at this point.
    before startKernel, os entered protected mode.
    Copyright (c) 2002 HigePon
    WITHOUT ANY WARRANTY

    \author  HigePon
    \version $Revision: 1.2 $
    \date   create:2002/07/21 update:$Date: 2003/03/24 15:53:04 $
*/
#include <kernel.h>

/*!
    \brief  mona kernel start at this point

    mona kernel start at this point.

    \author HigePon
    \date   create:2002/07/21 update:
*/
void cstart(void) {
    startKernel();
}
